@@ -8,12 +8,11 @@
 A basic ftpd storing passwords as hash digests (platform independent).
 """
 
+import hashlib
 import os
-import sys
-from hashlib import md5
 
-from pyftpdlib.authorizers import AuthenticationFailed
 from pyftpdlib.authorizers import DummyAuthorizer
+from pyftpdlib.exceptions import AuthenticationFailed
 from pyftpdlib.handlers import FTPHandler
 from pyftpdlib.servers import FTPServer
 
@@ -21,25 +20,24 @@ from pyftpdlib.servers import FTPServer
 class DummyMD5Authorizer(DummyAuthorizer):
 
     def validate_authentication(self, username, password, handler):
-        if sys.version_info >= (3, 0):
-            password = md5(password.encode('latin1'))
-        hash = md5(password).hexdigest()
+        hash_ = hashlib.md5(password.encode("latin1")).hexdigest()
         try:
-            if self.user_table[username]['pwd'] != hash:
+            if self.user_table[username]["pwd"] != hash_:
                 raise KeyError
         except KeyError:
-            raise AuthenticationFailed
+            raise AuthenticationFailed from None
 
 
 def main():
     # get a hash digest from a clear-text password
-    hash = md5(b'12345').hexdigest()
+    password = "12345"
+    hash_ = hashlib.md5(password.encode("latin1")).hexdigest()
     authorizer = DummyMD5Authorizer()
-    authorizer.add_user('user', hash, os.getcwd(), perm='elradfmwMT')
+    authorizer.add_user("user", hash_, os.getcwd(), perm="elradfmwMT")
     authorizer.add_anonymous(os.getcwd())
     handler = FTPHandler
     handler.authorizer = authorizer
-    server = FTPServer(('', 2121), handler)
+    server = FTPServer(("", 2121), handler)
     server.serve_forever()
 
 
