@@ -1,7 +1,7 @@
 #!/usr/bin/env python3
 
-# Copyright (c) 2009 Giampaolo Rodola'. All rights reserved.
-# Use of this source code is governed by a BSD-style license that can be
+# Copyright (C) 2007 Giampaolo Rodola' <g.rodola@gmail.com>.
+# Use of this source code is governed by MIT license that can be
 # found in the LICENSE file.
 
 """
@@ -11,10 +11,9 @@ Generate MANIFEST.in file.
 import os
 import subprocess
 
-
-SKIP_EXTS = ('.png', '.jpg', '.jpeg', '.svg')
-SKIP_FILES = 'appveyor.yml'
-SKIP_PREFIXES = ('.ci/', '.github/')
+SKIP_EXTS = (".png", ".jpg", ".jpeg", ".svg")
+SKIP_FILES = tuple()
+SKIP_PREFIXES = (".ci/", ".github/")
 
 
 def sh(cmd):
@@ -22,7 +21,7 @@ def sh(cmd):
 
 
 def main():
-    files = sh(["git", "ls-files"]).split('\n')
+    files = sh(["git", "ls-files"]).split("\n")
     for file in files:
         if (
             file.startswith(SKIP_PREFIXES)
@@ -32,6 +31,8 @@ def main():
             continue
         print("include " + file)
 
+    print("recursive-exclude docs/images *")
 
-if __name__ == '__main__':
+
+if __name__ == "__main__":
     main()
